% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/niche.par.plot.R
\name{niche.par.plot}
\alias{niche.par.plot}
\title{Plot for niche parameters.}
\usage{
niche.par.plot(
  niche.par,
  plot.mu = TRUE,
  plot.Sigma = TRUE,
  plot.index,
  col,
  ndens = 512,
  ylab
)
}
\arguments{
\item{niche.par}{List with \code{nspecies = length(niche.par)}, each element of which is a list with parameters \code{mu} and \code{Sigma}.  See 'Details'.}

\item{plot.mu}{Logical.  If \code{TRUE}, plot the distribution of \eqn{\mu} for each niche indicator (e.g., stable isotope).  See 'Details'.}

\item{plot.Sigma}{Logical.  If \code{TRUE}, plot the distribution of \eqn{\Sigma} for each niche indicator.  See 'Details'.}

\item{plot.index}{Either a scalar of a numeric vector of length 2.  If \code{plot.index = i} then plot the distribution of \eqn{\mu_i}.  If \code{plot.index = c(i,j)} then plot the distribution of \eqn{\Sigma_{ij}}.}

\item{col}{Vector of colors in which to plot each species.}

\item{ndens}{Number of points at which to evaluate density estimates.}

\item{ylab}{Optional label for \eqn{y}-axis.  If missing, defaults to \eqn{p(\mu_i | X)} and \eqn{p(\Sigma_{ij} | X)}.}
}
\value{
Returns a plot of the distribution of some or all niche parameters.
}
\description{
For one or more species, plots some or all of the niche parameters \eqn{\mu} and \eqn{\Sigma}.
}
\details{
Each element of the list \code{niche.par} is a distribution of niche parameters.  That is, \code{names(niche.par[[1]]) = c("mu", "Sigma")}, and if \code{niso} is the number of niche indicators (e.g., stable isotopes), then \code{dim(niche.par[[1]]$mu) = c(nsamples, niso)} and \code{dim(niche.par[[1]]$Sigma) = c(niso, niso, nsamples)}.
}
\examples{
# fish data
data(fish)

# generate parameter draws from the "default" posteriors of each fish
nsamples <- 1e3
system.time({
  fish.par <- tapply(1:nrow(fish), fish$species,
                     function(ii) niw.post(nsamples = nsamples, X = fish[ii,2:4]))
})

# various parameter plots
clrs <- c("black", "red", "blue", "orange") # colors for each species

# mu1, mu2, and Sigma12
par(mar = c(4, 4, .5, .1)+.1, mfrow = c(1,3))
niche.par.plot(fish.par, col = clrs, plot.index = 1)
niche.par.plot(fish.par, col = clrs, plot.index = 2)
niche.par.plot(fish.par, col = clrs, plot.index = 1:2)
legend("topright", legend = names(fish.par), fill = clrs)

# all mu
niche.par.plot(fish.par, col = clrs, plot.mu = TRUE, plot.Sigma = FALSE)
legend("topright", legend = names(fish.par), fill = clrs)

# all mu and Sigma
par(mar = c(4.2, 4.2, 2, 1)+.1)
niche.par.plot(fish.par, col = clrs, plot.mu = TRUE, plot.Sigma = TRUE)
legend("topright", legend = names(fish.par), fill = clrs)
}
\seealso{
\code{\link[=niw.post]{niw.post()}}, \code{\link[=niiw.post]{niiw.post()}} for niche parameter output, \code{\link[stats:density]{stats::density()}} for density estimation from sample data.
}
